@@ -47,6 +47,8 @@ class indice:
 
     def layer_stack(self, start_date, end_date, cloud_threshold, data_days_interval, indice_name='ndvi',
                     shp_file=None, bbox=None):
+        cloud_threshold = int(cloud_threshold)
+        data_days_interval = int(data_days_interval)
         if shp_file:
             shp_file = shp_file.replace('\\', '/')
         pids = s2.get_product_ids(start_date, end_date, cloud_threshold, data_days_interval, shp_file, bbox)
